summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2009-07-23 12:53:06 -0500
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2009-07-23 12:53:06 -0500
commit3f705ba9a5e7629080f14898959daf2397693c82 (patch)
tree5497b6d16b8f2a56889f1c7d241d6063bffecd27
parent8f075be1e27eef0a816d7124cf0c352ddfc6b143 (diff)
downloadlibpng-3f705ba9a5e7629080f14898959daf2397693c82.tar.gz
[devel] Added a prototype for png_64bit_product()
in png.c (suggested by Peter Breitenlohner)
-rw-r--r--ANNOUNCE5
-rw-r--r--CHANGES3
-rw-r--r--png.c18
3 files changed, 16 insertions, 10 deletions
diff --git a/ANNOUNCE b/ANNOUNCE
index 8a0b81335..239b4d2cc 100644
--- a/ANNOUNCE
+++ b/ANNOUNCE
@@ -1,5 +1,5 @@
-Libpng 1.4.0beta69 - July 20, 2009
+Libpng 1.4.0beta69 - July 23, 2009
This is not intended to be a public release. It will be replaced
within a few weeks by a public version or by another test version.
@@ -502,12 +502,13 @@ version 1.4.0beta67 [July 6, 2009]
version 1.4.0beta68 [July 19, 2009]
Avoid some tests in filter selection in pngwutil.c
-version 1.4.0beta69 [July 20, 2009]
+version 1.4.0beta69 [July 23, 2009]
Simplified the new filter-selection test. This runs faster in the
common "PNG_ALL_FILTERS" and PNG_FILTER_NONE cases.
Removed extraneous declaration from the new call to png_read_gray_to_rgb()
(bug introduced in libpng-1.4.0beta67).
Fixed up xcode project (Alam Arias)
+ Declared internal png_64bit_product() static.
version 1.4.0betaN [future]
Build shared libraries with -lz and sometimes -lm.
diff --git a/CHANGES b/CHANGES
index 8f970997f..3c6306586 100644
--- a/CHANGES
+++ b/CHANGES
@@ -2181,12 +2181,13 @@ version 1.4.0beta67 [July 6, 2009]
version 1.4.0beta68 [July 19, 2009]
Avoid some tests in filter selection in pngwutil.c
-version 1.4.0beta69 [July 20, 2009]
+version 1.4.0beta69 [July 23, 2009]
Simplified the new filter-selection test. This runs faster in the
common "PNG_ALL_FILTERS" and PNG_FILTER_NONE cases.
Removed extraneous declaration from the new call to png_read_gray_to_rgb()
(bug introduced in libpng-1.4.0beta67).
Fixed up xcode project (Alam Arias)
+ Added a prototype for png_64bit_product() in png.c
version 1.4.0betaN [future]
Build shared libraries with -lz and sometimes -lm.
diff --git a/png.c b/png.c
index 6780bd5af..16b76f324 100644
--- a/png.c
+++ b/png.c
@@ -1,7 +1,7 @@
/* png.c - location for general purpose libpng functions
*
* Last changed in libpng 1.4.0 [July 19, 2009]
* Copyright (c) 1998-2009 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -134,7 +134,7 @@ png_sig_cmp(png_bytep sig, png_size_t start, png_size_t num_to_check)
#if defined(PNG_READ_SUPPORTED) || defined(PNG_WRITE_SUPPORTED)
/* Function to allocate memory for zlib and clear it to 0. */
-voidpf /* private */
+voidpf /* PRIVATE */
png_zalloc(voidpf png_ptr, uInt items, uInt size)
{
png_voidp ptr;
@@ -159,7 +159,7 @@ png_zalloc(voidpf png_ptr, uInt items, uInt size)
}
/* Function to free memory for zlib */
-void /* private */
+void /* PRIVATE */
png_zfree(voidpf png_ptr, voidpf ptr)
{
png_free((png_structp)png_ptr, (png_voidp)ptr);
@@ -652,13 +652,13 @@ png_get_copyright(png_structp png_ptr)
#else
#ifdef __STDC__
return ((png_charp) PNG_STRING_NEWLINE \
- "libpng version x 1.4.0beta69 - July 19, 2009" PNG_STRING_NEWLINE \
+ "libpng version x 1.4.0beta69 - July 23, 2009" PNG_STRING_NEWLINE \
"Copyright (c) 1998-2009 Glenn Randers-Pehrson" PNG_STRING_NEWLINE \
"Copyright (c) 1996-1997 Andreas Dilger" PNG_STRING_NEWLINE \
"Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc." \
PNG_STRING_NEWLINE);
#else
- return ((png_charp) "libpng version 1.4.0beta69 - July 19, 2009\
+ return ((png_charp) "libpng version 1.4.0beta69 - July 23, 2009\
Copyright (c) 1998-2009 Glenn Randers-Pehrson\
Copyright (c) 1996-1997 Andreas Dilger\
Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.");
@@ -776,7 +776,11 @@ png_convert_size(size_t size)
* A and D, and X || Y is (X << 16) + Y.
*/
-void png_64bit_product (long v1, long v2, unsigned long *hi_product,
+void /* PRIVATE */
+png_64bit_product (long v1, long v2, unsigned long *hi_product,
+ unsigned long *lo_product);
+void /* PRIVATE */
+png_64bit_product (long v1, long v2, unsigned long *hi_product,
unsigned long *lo_product)
{
int a, b, c, d;
@@ -800,7 +804,7 @@ void png_64bit_product (long v1, long v2, unsigned long *hi_product,
*lo_product = (unsigned long)lo;
}
-int /* private */
+int /* PRIVATE */
png_check_cHRM_fixed(png_structp png_ptr,
png_fixed_point white_x, png_fixed_point white_y, png_fixed_point red_x,
png_fixed_point red_y, png_fixed_point green_x, png_fixed_point green_y,
@@ -1,7 +1,7 @@
/* png.c - location for general purpose libpng functions
*
- * Last changed in libpng 1.4.0 [July 19, 2009]
+ * Last changed in libpng 1.4.0 [July 23, 2009]
* Copyright (c) 1998-2009 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)